@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.65 2005/07/29 20:12:55 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.65.4.1 2005/10/02 18:49:57 chpe Exp $
  */
 
 #include "config.h"
@@ -368,6 +368,23 @@ ephy_embed_base_init (gpointer g_class)
 			      1,
 			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
+/**
+ * EphyEmbed::close-request
+ * @embed:
+ *
+ * The ::close signal is emitted when the embed request closing.
+ * Return %TRUE to prevent closing. You HAVE to process removal of the embed
+ * as soon as possible after that.
+ **/
+		g_signal_new ("close-request",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, close_request),
+			      g_signal_accumulator_true_handled, NULL,
+			      ephy_marshal_BOOLEAN__VOID,
+			      G_TYPE_BOOLEAN,
+			      0);
+
 		initialized = TRUE;
 	}
 }
@@ -731,6 +748,19 @@ ephy_embed_show_page_certificate (EphyEmbed *embed)
 	iface->show_page_certificate (embed);
 }
 
+/**
+ * ephy_embed_close:
+ * @embed: an #EphyEmbed
+ *
+ * Closes the @embed
+ **/
+void
+ephy_embed_close (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->close (embed);
+}
+
 /**
  * ephy_embed_set_encoding:
  * @embed: an #EphyEmbed
