@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.h,v 1.55 2005/06/03 13:42:34 chpe Exp $
+ *  $Id: ephy-embed.h,v 1.56.4.2 2005/10/02 18:49:57 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_H
@@ -51,7 +51,8 @@ typedef enum
 	EPHY_EMBED_STATE_IS_REQUEST	= 1 << 5,
 	EPHY_EMBED_STATE_IS_DOCUMENT	= 1 << 6,
 	EPHY_EMBED_STATE_IS_NETWORK	= 1 << 7,
-	EPHY_EMBED_STATE_IS_WINDOW	= 1 << 8
+	EPHY_EMBED_STATE_IS_WINDOW	= 1 << 8,
+	EPHY_EMBED_STATE_RESTORING	= 1 << 9
 } EphyEmbedNetState;
 
 typedef enum
@@ -148,6 +149,7 @@ struct _EphyEmbedIface
 					 EphyEmbed *new_embed);
 	gboolean (* search_key_press)	(EphyEmbed *embed,
 					 GdkEventKey *event);
+	gboolean (* close_request)	(EphyEmbed *embed);
 
 	/* Methods  */
 	void		   (* load_url)			(EphyEmbed *embed,
@@ -195,8 +197,8 @@ struct _EphyEmbedIface
 	void		   (* print_preview_navigate)	(EphyEmbed *embed,
 							 EphyEmbedPrintPreviewNavType type,
 							 int page);
-	void		   (* activate)			(EphyEmbed *embed);
 	gboolean	   (* has_modified_forms)	(EphyEmbed *embed);
+	void		   (* close)			(EphyEmbed *embed);
 };
 
 GType 		  ephy_embed_net_state_get_type		(void);
@@ -290,7 +292,7 @@ void		  ephy_embed_print_preview_navigate	(EphyEmbed *embed,
 							 int page);
 
 /* Misc. utility */
-void		  ephy_embed_activate			(EphyEmbed *embed);
+void		  ephy_embed_close			(EphyEmbed *embed);
 
 gboolean	  ephy_embed_has_modified_forms		(EphyEmbed *embed);
 
