@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.22.2.1 2005/04/26 12:02:28 chpe Exp $
+ *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.24.4.1 2006/02/02 22:28:04 chpe Exp $
  */
 
 /*
@@ -40,18 +40,19 @@
 #include "config.h"
 
 #include "EphyUtils.h"
+#include "AutoJSContextStack.h"
 
 #include <nsIServiceManager.h>
 #include <nsIInterfaceRequestor.h>
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsIKeygenThread.h>
+#include <nsIDOMWindow.h>
 
 #ifdef HAVE_GECKO_1_8
 #include <nsIObserver.h>
 #else /* !HAVE_GECKO_1_8 */
-#include <nsIDOMWindow.h>
 #ifdef ALLOW_PRIVATE_API
-#include "nsIDOMWindowInternal.h"
+#include <nsIDOMWindowInternal.h>
 #endif /* ALLOW_PRIVATE_API */
 #endif /* HAVE_GECKO_1_8 */
 
@@ -197,6 +198,10 @@ GtkNSSKeyPairDialogs::DisplayGeneratingKeypairInfo (nsIInterfaceRequestor *ctx,
 	GtkWidget *dialog, *progress, *label, *vbox;
 	gint timeout_id;
 
+	nsresult rv;
+	AutoJSContextStack stack;
+	rv = stack.Init ();
+	if (NS_FAILED (rv)) return rv;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
 	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
