@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.97 2005/06/16 12:38:13 chpe Exp $
+ *  $Id: ephy-history-window.c,v 1.97.4.1 2005/10/31 18:52:07 chpe Exp $
  */
 
 #include "config.h"
@@ -480,7 +480,7 @@ cmd_bookmark_link (GtkAction *action,
         GtkWidget *new_bookmark;
         GList *selection;
 
-        window = GTK_WINDOW(get_target_window (editor));
+	window = GTK_WINDOW (editor);
         bookmarks = ephy_shell_get_bookmarks (ephy_shell);
 
         selection = ephy_node_view_get_selection (EPHY_NODE_VIEW (editor->priv->pages_view));
